@@ -2,5 +2,5 @@
 # See: https://stackoverflow.com/questions/4042905/what-is-main-py
 from simplewallet.main import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 	raise SystemExit(main())
\ No newline at end of file
