@@ -4,12 +4,12 @@ from .gui.instance import Instance
 from .gui.addressgui import AddressGui
 from .gui.signergui import SignerGui
 from .gui.verifiergui import VerifierGui
-from .utils.configparser import ConfigParser
+from .utils.configloader import ConfigLoader
 
 def main():
 	simplewallet = SimpleWallet()
-	configparser = ConfigParser()
-	instance = Instance(configparser)
+	configloader = ConfigLoader()
+	instance = Instance(configloader)
 	addressgui = AddressGui(simplewallet, instance)
 	signergui = SignerGui(simplewallet, instance)
 	verifiergui = VerifierGui(simplewallet, instance)
@@ -17,5 +17,5 @@ def main():
 							addressgui, signergui, verifiergui)
 	simplewalletgui.run()
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 	raise SystemExit(main())
\ No newline at end of file
